import { Draft } from './immupdate';
import type { Pipe } from './lift';
/** A Map wrapper providing extra functionalities and more chaining opportunities */
export declare class MapWrapper<K, V, M extends ReadonlyMap<K, V>> {
    private _value;
    constructor(_value: M);
    private _isLiftWrapper;
    value(): M;
    clone(): MapWrapper<K, V, M>;
    private _clone;
    /**
     * Sets a new key/value.
     */
    set(key: K, value: V): MapWrapper<unknown, unknown, Map<K, V>>;
    /**
     * Deletes a key/value.
     */
    delete(key: K): MapWrapper<unknown, unknown, Map<K, V>>;
    /**
     * Clears the map.
     */
    clear(): MapWrapper<unknown, unknown, Map<K, V>>;
    /**
     * Maps this Map's keys and values, unless void or undefined is returned, in which case the entry is filtered.
     */
    collect<KK, VV>(iterator: (key: K, value: V) => [KK, VV] | undefined | void): MapWrapper<KK, VV, MapOf<M, KK, VV>>;
    /**
     * Filters this Map's keys and values by aplying a predicate to all values and refine its type.
     */
    filter<VV extends V>(predicate: (key: K, value: V) => value is VV): MapWrapper<K, VV, MapOf<M, K, VV>>;
    /**
     * Filters this Map's keys and values.
     */
    filter(predicate: (key: K, value: V) => boolean): this;
    /**
     * Maps this map's value.
     */
    mapValues<VV>(mapFunction: (value: V) => VV): MapWrapper<K, VV, MapOf<M, K, VV>>;
    /**
     * Make mutable modifications to a draft then return a new Map.
     */
    update(updateFunction: (draft: Draft<ReadonlyMap<K, V>>) => void): import("./lift").Lifted<M>;
    pipe: typeof import("./lift").pipe;
    toArray(): import("./array").ArrayWrapper<[K, V][]>;
}
export declare function setMapPipe(_pipe: Pipe): void;
declare type MapOf<T extends ReadonlyMap<unknown, unknown>, K, V> = T extends Map<any, any> ? Map<K, V> : ReadonlyMap<K, V>;
export {};
