import { ArrayWrapper } from './array';
import { Draft } from './immupdate';
import type { Pipe } from './lift';
export declare class ObjectWrapper<T extends object> {
    private _value;
    constructor(_value: T);
    private _isLiftWrapper;
    value(): T;
    clone(): ObjectWrapper<T>;
    private _clone;
    /**
     * Adds a new key/value to this object. This creates a new type.
     * To add a nullable key to an object while preserving its type, use "update()" instead.
     */
    add<K extends string, V>(key: K, value: V): ObjectWrapper<T & {
        [P in K]: V;
    }>;
    /**
     * Returns whether this object contains no keys.
     */
    isEmpty(): boolean;
    /**
     * Creates an Array of all this object's keys, in no particular order.
     */
    keys(): ArrayWrapper<Array<keyof T>>;
    pipe: typeof import("./lift").pipe;
    /**
     * Removes a key/value from this object and return a new object (and type)
     * To delete a (nullable) key from an object while preserving its type, use "update()" instead.
     */
    remove<K extends keyof T>(keyToRemove: K): ObjectWrapper<Omit<T, K>>;
    /**
     * Creates an Array with all these object's values.
     */
    values(): ArrayWrapper<Array<keyof T>>;
    /**
     * Make mutable modifications to a draft then return a new Object.
     * Example: lift({a: 1}).update(draft => {draft.a = 10})
     */
    update(updateFunction: (draft: Draft<T>) => void): import("./lift").Lifted<T>;
}
export declare function setObjectPipe(_pipe: Pipe): void;
