import { update } from './immupdate';
/** A Map wrapper providing extra functionalities and more chaining opportunities */
export class MapWrapper {
    constructor(_value) {
        this._value = _value;
        this._isLiftWrapper = true;
        this.pipe = pipe;
    }
    value() {
        return this._value;
    }
    clone() {
        return new MapWrapper(this._clone());
    }
    _clone() {
        return new Map(this._value);
    }
    /**
     * Sets a new key/value.
     */
    set(key, value) {
        return new MapWrapper(this._clone().set(key, value));
    }
    /**
     * Deletes a key/value.
     */
    delete(key) {
        const result = this._clone();
        result.delete(key);
        return new MapWrapper(result);
    }
    /**
     * Clears the map.
     */
    clear() {
        const result = this._clone();
        result.clear();
        return new MapWrapper(result);
    }
    /**
     * Maps this Map's keys and values, unless void or undefined is returned, in which case the entry is filtered.
     */
    collect(iterator) {
        const result = new Map();
        this._value.forEach((value, key) => {
            const res = iterator(key, value);
            if (res !== undefined)
                result.set(res[0], res[1]);
        });
        return new MapWrapper(result);
    }
    filter(predicate) {
        return this.collect((key, value) => (predicate(key, value) ? [key, value] : undefined));
    }
    /**
     * Maps this map's value.
     */
    mapValues(mapFunction) {
        return this.collect((key, value) => [key, mapFunction(value)]);
    }
    /**
     * Make mutable modifications to a draft then return a new Map.
     */
    update(updateFunction) {
        return this.pipe(o => update(o, updateFunction));
    }
    toArray() {
        return this.pipe(m => [...m]);
    }
}
let pipe;
export function setMapPipe(_pipe) {
    pipe = _pipe;
}
